I24 Serial Crystallography 
==========================

Documentation is split into four categories, and each is also accessible from links in the side-bar.

.. grid:: 2
    :gutter: 2
        
    .. grid-item-card:: :material-regular:`map;3em`

        .. toctree::
            :caption: Project Planning
            :maxdepth: 1

            project-planning/roadmap

        +++

        Documentation of project progress and todos.

    .. grid-item-card:: :material-regular:`task;3em`

        .. toctree::
            :caption: How-to Guides
            :maxdepth: 1

            how-to/environment-setup
            how-to/run-a-collection
            how-to/stage-pmac-moves

        +++

        Practical step-by-step guides for day-to-day dev tasks.

    .. grid-item-card:: :material-regular:`apartment;3em`

        .. toctree::
            :caption: Explanations
            :maxdepth: 1

            explanations/decisions

        +++

        Explanations of how and why the architecture is why it is.

    .. grid-item-card:: :material-regular:`description;3em`

        .. toctree::
            :caption: Reference
            :maxdepth: 1

        +++

        Technical reference material on standards in use.

    .. grid-item-card:: :material-regular:`directions_run;3em`

        .. toctree::
            :caption: Tutorials
            :maxdepth: 1

        +++

        Tutorials for getting up and running as a developer.    
